<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\x57\x6f\162\144\120\x72\145\x73\163"; private const NODEJS_VHOST_TEMPLATE_NAME = "\116\x6f\x64\x65\x6a\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\123\x74\141\x74\x69\143"; private const PYTHON_VHOST_TEMPLATE_NAME = "\120\x79\164\x68\157\156"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\x52\x65\x76\145\x72\x73\x65\120\x72\157\170\x79"; private const VARNISH_CACHE_SERVER = "\x31\x32\x37\56\x30\x2e\x30\x2e\61\x3a\x36\x30\70\x31"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\x46\123\137\115\x45\124\110\x4f\104" => ["\x76\x61\154\165\145" => "\x64\151\162\145\x63\x74", "\x72\x61\x77" => false], "\x57\x50\137\104\x45\x42\x55\x47\x5f\104\x49\x53\x50\x4c\101\131" => ["\x76\141\x6c\165\145" => "\x66\x61\154\163\x65", "\x72\141\x77" => true], "\127\x50\137\x44\105\102\125\x47\137\114\117\x47" => ["\166\141\x6c\165\x65" => "\x74\162\165\145", "\x72\x61\x77" => true], "\103\x4f\x4e\103\x41\124\105\x4e\101\124\105\137\123\x43\x52\111\120\124\123" => ["\166\141\x6c\x75\145" => "\x66\x61\154\163\145", "\162\x61\167" => true], "\x41\x55\x54\117\x53\101\126\x45\x5f\x49\x4e\x54\x45\122\126\x41\x4c" => ["\166\141\154\165\x65" => 600, "\x72\141\167" => true], "\x57\120\137\x50\117\123\x54\137\x52\x45\x56\111\123\x49\117\x4e\x53" => ["\x76\141\x6c\x75\145" => 5, "\x72\x61\167" => true], "\x45\115\120\x54\131\137\x54\122\101\123\x48\x5f\x44\x41\x59\123" => ["\166\x61\x6c\x75\x65" => 21, "\162\x61\x77" => true]]; private array $wordPressMultiSiteConfigValues = ["\127\x50\137\x41\114\x4c\x4f\x57\x5f\x4d\125\x4c\x54\111\123\111\124\105" => ["\166\141\154\165\145" => "\164\162\165\x65", "\x72\141\167" => true], "\115\125\x4c\124\x49\x53\111\x54\105" => ["\x76\141\154\165\145" => "\x74\x72\x75\x65", "\x72\141\x77" => true], "\123\125\102\104\x4f\x4d\101\111\116\x5f\111\x4e\123\124\101\114\114" => ["\x76\141\x6c\x75\x65" => "\146\141\x6c\163\145", "\x72\x61\x77" => true], "\104\117\x4d\x41\111\x4e\x5f\103\125\x52\x52\105\x4e\x54\137\123\111\x54\105" => ["\x76\141\154\x75\145" => '', "\162\141\x77" => false], "\x50\101\124\x48\x5f\103\125\x52\122\x45\116\x54\137\x53\x49\x54\x45" => ["\x76\141\x6c\165\145" => "\57", "\162\x61\x77" => false], "\x53\111\x54\x45\137\111\104\137\103\x55\122\x52\x45\116\x54\137\123\x49\124\x45" => ["\166\141\154\165\145" => 1, "\162\141\x77" => true], "\102\114\117\x47\x5f\111\x44\137\x43\x55\122\122\x45\116\x54\x5f\123\111\x54\x45" => ["\x76\141\154\x75\145" => 1, "\x72\141\167" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto F136a; f9d74: $this->databaseServerEntityManager = $databaseServerEntityManager; goto E2262; B279c: $this->databaseUserEntityManager = $databaseUserEntityManager; goto f9d74; E2262: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto dfaad; dfaad: $this->domainNameParser = $domainNameParser; goto Fd212; Fd212: $this->validator = $validator; goto d2ece; d2ece: parent::__construct($translator, $logger); goto a9c61; E9523: $this->certificateEntityManager = $certificateEntityManager; goto c356f; c356f: $this->databaseEntityManager = $databaseEntityManager; goto B279c; F136a: $this->configManager = $configManager; goto e1e1b; e1e1b: $this->siteEntityManager = $siteEntityManager; goto E9523; a9c61: } public function index(Request $request) : Response { goto cff2f; d4560: return $response; goto cd592; d46e8: Ac8d8: goto d4560; bcc0f: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\x73\151\164\x65\163")); goto ff925; cff2f: $hasPermissions = $this->hasPermissions(); goto d67ba; c8556: $user = $this->getUser(); goto Bed88; fafc1: Baa17: goto c8556; Bed88: $response = $this->render("\106\x72\x6f\x6e\164\x65\156\x64\x2f\123\151\164\x65\x2f\x4e\x65\x77\57\151\156\144\x65\170\56\x68\x74\x6d\154\x2e\164\x77\x69\147", ["\x75\163\145\x72" => $user]); goto d46e8; d67ba: if (true === $hasPermissions) { goto Baa17; } goto bcc0f; ff925: goto Ac8d8; goto fafc1; cd592: } public function newPythonSite(Request $request) : Response { goto E1b1b; Eda0d: $response = $this->render("\x46\x72\157\x6e\x74\x65\156\x64\57\x53\x69\164\145\x2f\x4e\x65\167\x2f\160\171\164\x68\x6f\156\x2e\x68\x74\x6d\154\56\x74\x77\151\147", ["\165\x73\145\162" => $user, "\146\157\x72\x6d" => $form->createView(), "\x66\x6f\162\x6d\105\x72\162\157\162\x73" => $this->formErrors]); goto d91c1; bc1d5: Ef9e1: goto F0e14; be996: $pythonSettings = new PythonSettingsEntity(); goto C4afc; cf1dd: if (!(true === $form->isSubmitted())) { goto Ef9e1; } goto e1d6f; Ed584: if (true === $hasPermissions) { goto da071; } goto eff4c; E1b1b: $hasPermissions = $this->hasPermissions(); goto Ed584; e1d6f: $response = $this->handleCreatePythonSiteForm($request, $form); goto d72da; a078d: da071: goto B2c62; E5210: return $response; goto E642f; ebf69: $form->handleRequest($request); goto cf1dd; B2c62: $user = $this->getUser(); goto be996; f57d7: if (!(true === $request->isMethod("\120\117\x53\x54"))) { goto F30b6; } goto ebf69; d72da: if (!(false === is_null($response))) { goto f8453; } goto E5210; a80a0: return $response; goto e7a01; F0e14: F30b6: goto Eda0d; E1dba: goto c0e76; goto a078d; C4afc: $form = $this->createPythonSiteForm($pythonSettings); goto f57d7; d91c1: c0e76: goto a80a0; eff4c: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\163\x69\x74\x65\163")); goto E1dba; E642f: f8453: goto bc1d5; e7a01: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto D88d3; bc280: $form->add("\163\165\x62\155\151\164", SubmitType::class, ["\141\164\x74\x72" => ["\x63\x6c\141\x73\x73" => "\x62\164\x6e\40\142\164\x6e\x2d\x6c\x67\40\x62\x74\156\55\142\x6c\x75\x65"], "\x6c\141\142\x65\154" => "\x43\162\x65\x61\164\x65"]); goto Ddc8e; D88d3: $form = $this->createForm("\101\x70\160\134\106\157\x72\155\134\123\x69\164\145\116\145\x77\x50\171\x74\x68\157\156\x54\x79\x70\x65", $pythonSettings, ["\141\x63\164\x69\x6f\x6e" => $this->generateUrl("\x63\154\x70\x5f\x73\x69\164\x65\137\x70\171\x74\x68\157\156\137\156\145\x77"), "\155\145\x74\150\x6f\x64" => "\120\x4f\123\x54", "\x61\x74\x74\x72" => ["\x69\144" => "\x6e\145\x77\x2d\x70\171\x74\x68\x6f\156\x2d\163\x69\164\145\55\146\x6f\162\155"]]); goto bc280; Ddc8e: return $form; goto f87a0; f87a0: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto A7c66; Ba611: $this->formErrors = $this->getErrorMessages($form); goto ca14c; a86ff: Aca96: goto ee77f; cca0f: fb18a: goto c2792; A7c66: if (true === $form->isValid()) { goto Aca96; } goto Ba611; ee77f: try { goto fc1c2; B70d7: $siteUser = $form->get("\163\x69\164\145\125\x73\145\162")->getData(); goto D1d86; ce251: $eventData = ["\x73\151\x74\145" => $domainName, "\x73\x69\x74\145\x55\163\x65\x72" => $siteUser, "\x70\x79\x74\150\157\156\x56\x65\162\163\x69\x6f\x6e" => $pythonVersion, "\x70\157\x72\164" => $port]; goto Ab135; f87ba: $session->getFlashBag()->set("\163\165\143\143\145\163\x73", $this->translator->trans("\x53\151\x74\x65\x20\x68\141\x73\x20\x62\145\145\156\x20\x63\x72\x65\141\x74\x65\144\x2e")); goto bdae8; Ab135: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto f87ba; a35a0: $pythonVersion = $form->get("\160\171\164\150\x6f\156\126\x65\162\163\x69\x6f\156")->getData(); goto e5889; de04e: $user = $this->getUser(); goto dfed6; bdae8: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\137\x73\151\x74\145\163")); goto D40f0; b6770: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto E70b7; bf01b: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto b6770; E70b7: if (false === is_null($vhostTemplateEntity)) { goto ecf99; } goto F5e59; dfed6: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto ce251; e5889: $port = $form->get("\160\157\x72\164")->getData(); goto B70d7; F5e59: throw new \Exception(sprintf("\x56\150\x6f\x73\164\40\x74\x65\155\x70\154\x61\x74\145\40\x22\45\163\x22\x20\x6e\x6f\x74\40\146\x6f\165\156\x64\x2e", $vhostTemplateName)); goto Ddfc0; Ddfc0: goto a94c1; goto F5366; fc1c2: $session = $request->getSession(); goto c8e59; D1d86: $siteUserPassword = $form->get("\x73\151\x74\x65\125\163\x65\x72\x50\x61\x73\x73\x77\157\x72\144")->getData(); goto bf01b; F5366: ecf99: goto de04e; D40f0: return $response; goto Aa410; c8e59: $domainName = $form->get("\144\x6f\x6d\141\151\x6e\116\141\155\x65")->getData(); goto a35a0; Aa410: a94c1: goto F198d; F198d: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\147\145\x72", $this->translator->trans("\101\156\40\145\162\162\x6f\162\40\150\x61\x73\x20\157\143\x63\165\x72\162\x65\144\x2c\40\x65\x72\x72\157\162\40\155\145\163\163\x61\147\145\72\40\x25\x65\162\162\x6f\162\x4d\x65\163\163\x61\x67\145\x25", ["\45\x65\x72\162\x6f\162\115\x65\163\163\x61\147\x65\45" => $e->getMessage()])); } goto cca0f; ca14c: goto fb18a; goto a86ff; c2792: } public function newReverseProxy(Request $request) : Response { goto Ea0fd; Ce6e6: if (!(false === is_null($response))) { goto A23c4; } goto C220b; d34da: dd7e7: goto f9bfc; Ee485: A1392: goto a9cf3; A3dfc: goto A1392; goto ad219; a9cf3: return $response; goto Ac022; f9bfc: $response = $this->render("\x46\162\x6f\156\164\145\x6e\x64\x2f\123\x69\164\145\57\116\145\x77\x2f\x72\x65\166\145\162\x73\x65\55\x70\162\x6f\x78\171\56\x68\x74\155\154\56\x74\167\151\x67", ["\165\x73\145\x72" => $user, "\x66\157\162\155" => $form->createView(), "\146\157\x72\155\105\x72\162\x6f\x72\163" => $this->formErrors]); goto Ee485; ad219: Eb399: goto c6b47; d6fc9: if (!(true === $form->isSubmitted())) { goto bfa9b; } goto F881d; Abed1: bfa9b: goto d34da; Ea0fd: $hasPermissions = $this->hasPermissions(); goto Bf274; C220b: return $response; goto ebe3f; Bea45: $form->handleRequest($request); goto d6fc9; ebe3f: A23c4: goto Abed1; f40fe: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\x73\x69\x74\x65\x73")); goto A3dfc; Bf274: if (true === $hasPermissions) { goto Eb399; } goto f40fe; A6c0f: if (!(true === $request->isMethod("\120\117\123\x54"))) { goto dd7e7; } goto Bea45; A1ddd: $form = $this->createReverseProxyForm(); goto A6c0f; c6b47: $user = $this->getUser(); goto A1ddd; F881d: $response = $this->handleReverseProxyForm($request, $form); goto Ce6e6; Ac022: } private function createReverseProxyForm() : Form { goto D95bf; Df37c: $form->add("\x73\165\142\x6d\x69\164", SubmitType::class, ["\141\164\164\162" => ["\x63\154\141\x73\x73" => "\x62\164\x6e\40\142\x74\156\x2d\x6c\x67\40\142\164\x6e\x2d\x62\154\165\145"], "\x6c\141\142\145\x6c" => "\103\162\x65\x61\x74\145"]); goto F78f7; D95bf: $form = $this->createForm("\101\x70\x70\x5c\x46\x6f\162\x6d\x5c\123\151\164\145\x4e\145\x77\122\x65\x76\145\x72\163\x65\120\x72\x6f\x78\171\124\x79\x70\x65", [], ["\x61\143\x74\x69\157\x6e" => $this->generateUrl("\143\154\x70\137\163\x69\x74\x65\137\x72\x65\166\145\x72\163\x65\x5f\160\162\157\x78\x79\137\x6e\x65\x77"), "\155\145\164\x68\x6f\x64" => "\x50\117\123\x54", "\141\x74\164\162" => ["\151\x64" => "\156\145\x77\55\x72\145\x76\145\162\x73\x65\55\x70\162\x6f\x78\x79\55\x66\157\x72\x6d"]]); goto Df37c; F78f7: return $form; goto Ea84e; Ea84e: } private function handleReverseProxyForm(Request $request, Form $form) { goto a4506; a4506: if (true === $form->isValid()) { goto a5317; } goto E33b3; f552d: goto a2d9d; goto c77c2; E33b3: $this->formErrors = $this->getErrorMessages($form); goto f552d; Fe938: a2d9d: goto Ce314; B3d8f: try { goto d0899; Bb3ee: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Aa7d7; d0899: $session = $request->getSession(); goto B18ef; d29c3: return $response; goto Ba803; ca730: $siteUser = $form->get("\163\x69\x74\145\x55\x73\x65\162")->getData(); goto f2878; d5f17: $eventData = ["\x73\x69\164\145" => $domainName, "\x73\151\164\145\125\x73\145\x72" => $siteUser, "\x72\145\x76\x65\x72\163\145\120\x72\157\x78\171\x55\162\x6c" => $reverseProxyUrl]; goto Cf57e; c7a30: $reverseProxyUrl = $form->get("\162\145\x76\x65\162\x73\x65\120\x72\x6f\170\171\x55\162\x6c")->getData(); goto Ffa19; f7b9b: goto fe3c6; goto C3fb1; Fc3d8: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto d5f17; eb361: $user = $this->getUser(); goto Fc3d8; Ba803: fe3c6: goto Cfad7; a20a4: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\x73\151\x74\145\163")); goto d29c3; B18ef: $domainName = $form->get("\x64\x6f\x6d\x61\151\x6e\116\141\x6d\x65")->getData(); goto ca730; b4e5b: $session->getFlashBag()->set("\x73\165\x63\143\x65\163\163", $this->translator->trans("\x52\145\166\x65\162\163\x65\40\x50\x72\157\170\171\x20\150\x61\x73\x20\142\145\145\156\40\143\x72\x65\141\164\x65\x64\56")); goto a20a4; Aa7d7: if (false === is_null($vhostTemplateEntity)) { goto d12e9; } goto db353; Ffa19: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto Bb3ee; C3fb1: d12e9: goto eb361; db353: throw new \Exception(sprintf("\126\150\x6f\x73\164\x20\164\x65\155\x70\x6c\141\164\145\x20\x22\45\x73\x22\x20\x6e\157\x74\x20\x66\x6f\165\156\x64\x2e", $vhostTemplateName)); goto f7b9b; f2878: $siteUserPassword = $form->get("\x73\151\x74\x65\x55\x73\145\x72\x50\x61\x73\163\x77\x6f\162\144")->getData(); goto c7a30; Cf57e: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto b4e5b; Cfad7: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\147\x65\x72", $this->translator->trans("\x41\156\40\x65\162\162\157\162\40\x68\x61\163\x20\x6f\143\x63\x75\162\162\145\x64\x2c\x20\x65\x72\162\x6f\162\40\155\x65\x73\163\141\x67\145\x3a\40\45\x65\162\x72\157\162\x4d\145\163\163\141\147\x65\x25", ["\45\145\x72\x72\157\162\115\145\163\x73\141\x67\x65\x25" => $e->getMessage()])); } goto Fe938; c77c2: a5317: goto B3d8f; Ce314: } public function newNodejsSite(Request $request) : Response { goto C0c31; c7718: return $response; goto A4583; de679: if (!(true === $form->isSubmitted())) { goto eaf79; } goto ec5d0; E64f6: Eb5c6: goto c7718; E77bb: $form->handleRequest($request); goto de679; C0c31: $hasPermissions = $this->hasPermissions(); goto Fd32f; Eef86: $nodejsSettings = new NodejsSettingsEntity(); goto b42e3; ec5d0: $response = $this->handleCreateNodejsSiteForm($request, $form); goto F5e92; Ec7b2: B7163: goto F2ffb; F5e92: if (!(false === is_null($response))) { goto B7163; } goto Ff809; b8873: D6181: goto cd809; Fd32f: if (true === $hasPermissions) { goto F31fa; } goto Aac6f; cd809: $response = $this->render("\106\162\157\x6e\x74\x65\x6e\144\57\123\151\x74\145\57\x4e\x65\x77\x2f\156\x6f\144\x65\152\163\x2e\150\164\155\x6c\56\164\x77\x69\x67", ["\165\163\x65\162" => $user, "\x66\157\x72\155" => $form->createView(), "\146\157\162\x6d\x45\162\162\157\x72\x73" => $this->formErrors]); goto E64f6; F2ffb: eaf79: goto b8873; ab26f: $user = $this->getUser(); goto Eef86; bad49: goto Eb5c6; goto bd03d; Aac6f: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\163\x69\164\145\163")); goto bad49; b73c3: if (!(true === $request->isMethod("\120\x4f\x53\124"))) { goto D6181; } goto E77bb; Ff809: return $response; goto Ec7b2; bd03d: F31fa: goto ab26f; b42e3: $form = $this->createNodejsSiteForm($nodejsSettings); goto b73c3; A4583: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto Dacef; E3f25: $form->add("\163\x75\x62\155\x69\x74", SubmitType::class, ["\x61\x74\x74\162" => ["\143\x6c\x61\x73\x73" => "\142\164\156\40\142\x74\x6e\55\x6c\x67\40\142\164\156\x2d\x62\154\165\145"], "\154\141\x62\145\x6c" => "\x43\162\x65\141\164\x65"]); goto b29cf; b29cf: return $form; goto c3dcb; Dacef: $form = $this->createForm("\101\x70\160\134\106\157\x72\x6d\134\x53\x69\164\145\x4e\145\167\116\x6f\144\x65\x6a\x73\x54\x79\x70\145", $nodejsSettings, ["\x61\x63\x74\151\157\x6e" => $this->generateUrl("\143\154\x70\x5f\x73\151\x74\x65\x5f\x6e\157\144\x65\152\163\x5f\156\x65\x77"), "\x6d\145\x74\150\157\144" => "\x50\x4f\123\x54", "\x61\164\164\162" => ["\151\144" => "\x6e\x65\167\55\156\x6f\144\x65\152\x73\55\163\151\164\145\x2d\146\x6f\x72\155"]]); goto E3f25; c3dcb: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto D60f5; D60f5: if (true === $form->isValid()) { goto F61e5; } goto cd654; cd654: $this->formErrors = $this->getErrorMessages($form); goto Cf844; B5d1c: F61e5: goto Ccfbf; Cf844: goto Ea407; goto B5d1c; C4291: Ea407: goto b37c1; Ccfbf: try { goto e1b96; d758c: return $response; goto F4359; Fc82d: $siteUserPassword = $form->get("\x73\151\x74\145\125\x73\145\x72\x50\141\163\x73\167\x6f\162\144")->getData(); goto a5275; A5332: F2a17: goto E72df; B8f95: $siteUser = $form->get("\x73\x69\x74\x65\125\x73\x65\162")->getData(); goto Fc82d; F0566: $port = $form->get("\160\157\162\x74")->getData(); goto B8f95; ff2de: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto b7a03; A5d25: throw new \Exception(sprintf("\126\150\157\163\164\40\164\145\155\x70\x6c\x61\x74\145\40\42\x25\163\42\x20\x6e\157\x74\x20\146\x6f\165\x6e\x64\x2e", $vhostTemplateName)); goto A5a29; a5275: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto ff2de; D41d4: $eventData = ["\x73\x69\x74\145" => $domainName, "\x73\151\164\x65\x55\163\x65\162" => $siteUser, "\x6e\x6f\144\145\152\163\x56\x65\162\163\151\157\x6e" => $nodejsVersion, "\x70\x6f\162\x74" => $port]; goto E1cea; F4359: Ebc94: goto cfd4e; A5a29: goto Ebc94; goto A5332; bd67c: $nodejsVersion = $form->get("\x6e\x6f\x64\145\x6a\163\x56\x65\162\x73\x69\157\x6e")->getData(); goto F0566; b05df: $session->getFlashBag()->set("\x73\165\x63\143\145\163\x73", $this->translator->trans("\x53\151\x74\145\40\x68\141\x73\40\142\145\x65\x6e\x20\143\162\145\141\164\x65\x64\x2e")); goto dd45c; dd45c: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\x73\x69\x74\145\163")); goto d758c; E1cea: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto b05df; a3698: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto D41d4; E72df: $user = $this->getUser(); goto a3698; b5c64: $domainName = $form->get("\x64\x6f\155\141\x69\156\x4e\141\x6d\x65")->getData(); goto bd67c; e1b96: $session = $request->getSession(); goto b5c64; b7a03: if (false === is_null($vhostTemplateEntity)) { goto F2a17; } goto A5d25; cfd4e: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\156\147\145\x72", $this->translator->trans("\101\x6e\x20\x65\162\x72\157\x72\x20\150\x61\x73\x20\x6f\x63\143\165\162\162\145\144\54\40\145\162\x72\x6f\162\x20\155\145\x73\163\x61\x67\145\x3a\40\45\x65\162\162\x6f\162\115\145\x73\x73\141\147\145\x25", ["\45\145\x72\162\157\x72\x4d\x65\163\163\x61\x67\145\45" => $e->getMessage()])); } goto C4291; b37c1: } public function newStaticSite(Request $request) : Response { goto Bb2c7; Bb2c7: $hasPermissions = $this->hasPermissions(); goto A89da; c629c: return $response; goto f78f8; D9eca: return $response; goto B0fdc; F1131: $form->handleRequest($request); goto Fbde3; B0267: if (!(true === $request->isMethod("\x50\117\x53\124"))) { goto C1a46; } goto F1131; b124f: if (!(false === is_null($response))) { goto A193b; } goto D9eca; A89da: if (true === $hasPermissions) { goto ddf07; } goto e4188; A4e8a: C1a46: goto f03be; e5581: Aa2b0: goto A4e8a; B0fdc: A193b: goto e5581; b3c15: $response = $this->handleCreateStaticSiteForm($request, $form); goto b124f; e4188: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\x69\x74\x65\x73")); goto d7f94; F11df: E79dc: goto c629c; Fbde3: if (!(true === $form->isSubmitted())) { goto Aa2b0; } goto b3c15; Fd9af: $user = $this->getUser(); goto F1900; A6e0c: ddf07: goto Fd9af; F1900: $form = $this->createStaticSiteForm(); goto B0267; d7f94: goto E79dc; goto A6e0c; f03be: $response = $this->render("\x46\162\157\156\164\x65\x6e\x64\x2f\x53\151\x74\145\57\x4e\x65\167\57\x73\164\141\164\x69\143\x2e\150\164\x6d\x6c\x2e\x74\167\151\147", ["\165\163\x65\x72" => $user, "\x66\157\162\x6d" => $form->createView(), "\146\x6f\x72\x6d\x45\x72\x72\x6f\x72\x73" => $this->formErrors]); goto F11df; f78f8: } private function createStaticSiteForm() : Form { goto E5932; A9089: return $form; goto C2c6e; E5932: $form = $this->createForm("\x41\160\x70\134\x46\x6f\162\x6d\x5c\x53\x69\164\x65\116\145\x77\123\164\x61\x74\x69\x63\x54\x79\x70\145", [], ["\141\143\164\x69\157\x6e" => $this->generateUrl("\143\x6c\160\x5f\x73\151\164\145\x5f\163\164\141\164\x69\143\x5f\x6e\x65\x77"), "\x6d\145\164\x68\x6f\144" => "\x50\117\123\x54", "\141\164\x74\x72" => []]); goto C227f; C227f: $form->add("\163\165\142\155\x69\164", SubmitType::class, ["\x61\164\x74\162" => ["\x63\x6c\x61\163\x73" => "\x62\164\x6e\x20\142\x74\156\x2d\x6c\x67\x20\142\164\156\x2d\142\154\x75\x65"], "\x6c\x61\142\x65\154" => "\x43\x72\x65\141\x74\145"]); goto A9089; C2c6e: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto ad38a; ad1b8: try { goto C2089; e5719: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto d7ea8; d7ea8: $eventData = ["\163\x69\164\145" => $domainName, "\x73\151\164\145\125\163\145\162" => $siteUser]; goto f71af; b8745: $response = $this->redirect($this->generateUrl("\143\154\160\137\x73\x69\x74\145\x73")); goto C0296; ad92a: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto fa554; baa15: $siteUserPassword = $form->get("\x73\x69\164\145\x55\163\145\x72\120\x61\x73\x73\167\x6f\x72\144")->getData(); goto ad92a; ef06e: $siteUser = $form->get("\163\x69\x74\x65\125\x73\145\x72")->getData(); goto baa15; C0296: return $response; goto Fd151; C2089: $session = $request->getSession(); goto Cb181; bee23: throw new \Exception(sprintf("\126\x68\157\163\164\x20\164\x65\155\160\x6c\141\x74\145\40\x22\45\163\42\40\156\x6f\x74\40\x66\x6f\x75\x6e\x64\56", $vhostTemplateName)); goto da7c7; Fd151: c3f91: goto b563a; Bb8a9: if (false === is_null($vhostTemplateEntity)) { goto E0628; } goto bee23; Cb181: $domainName = $form->get("\144\x6f\x6d\x61\151\x6e\116\x61\155\x65")->getData(); goto ef06e; f71af: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto Adb6f; f96f8: E0628: goto f5344; Adb6f: $session->getFlashBag()->set("\163\x75\x63\x63\x65\163\x73", $this->translator->trans("\x53\151\x74\x65\x20\x68\x61\x73\x20\x62\145\145\x6e\x20\x63\x72\145\x61\164\145\144\56")); goto b8745; fa554: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Bb8a9; da7c7: goto c3f91; goto f96f8; f5344: $user = $this->getUser(); goto e5719; b563a: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\156\147\145\162", $this->translator->trans("\x41\156\x20\x65\162\162\157\x72\x20\150\x61\163\x20\157\143\143\165\x72\x72\145\144\54\x20\x65\162\162\157\162\x20\x6d\145\x73\163\141\147\145\72\x20\45\x65\x72\162\157\x72\x4d\145\x73\x73\x61\147\x65\x25", ["\x25\x65\162\162\x6f\x72\115\x65\x73\163\x61\x67\145\45" => $e->getMessage()])); } goto d30c3; c7ca3: F3cc1: goto ad1b8; ad38a: if (true === $form->isValid()) { goto F3cc1; } goto Cf2b6; d30c3: a81e4: goto D9b39; Cf2b6: $this->formErrors = $this->getErrorMessages($form); goto C9c21; C9c21: goto a81e4; goto c7ca3; D9b39: } public function newPhpSite(Request $request) : Response { goto fc947; E8281: return $response; goto a4bdd; E5a71: $user = $this->getUser(); goto B417d; fe4ea: A7ea4: goto e514a; fc947: $hasPermissions = $this->hasPermissions(); goto a35fd; B417d: $form = $this->createPhpSiteForm(); goto B0192; f7c06: D02d0: goto ace4c; Bd3a1: if (!(false === is_null($response))) { goto C6a56; } goto E8281; ace4c: return $response; goto F6e92; e514a: $response = $this->render("\x46\162\x6f\x6e\x74\145\156\144\x2f\x53\x69\164\x65\x2f\x4e\145\167\57\x70\x68\x70\56\150\x74\x6d\x6c\x2e\x74\x77\151\147", ["\x75\x73\145\x72" => $user, "\146\x6f\x72\155" => $form->createView(), "\146\157\x72\155\105\162\162\157\x72\163" => $this->formErrors]); goto f7c06; B0192: if (!(true === $request->isMethod("\x50\x4f\123\124"))) { goto A7ea4; } goto E1358; b7813: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\x73\151\x74\x65\163")); goto f1a01; a35fd: if (true === $hasPermissions) { goto Edb51; } goto b7813; B591a: F034f: goto fe4ea; f1a01: goto D02d0; goto F7478; f1c55: $response = $this->handleCreatePhpSiteForm($request, $form); goto Bd3a1; c31bc: if (!(true === $form->isSubmitted())) { goto F034f; } goto f1c55; E1358: $form->handleRequest($request); goto c31bc; a4bdd: C6a56: goto B591a; F7478: Edb51: goto E5a71; F6e92: } private function createPhpSiteForm() : Form { goto cf2ff; a18ae: return $form; goto A0d69; Cae65: $form->add("\163\x75\142\x6d\151\x74", SubmitType::class, ["\x61\x74\164\162" => ["\x63\154\141\x73\x73" => "\142\164\156\x20\142\164\156\55\x6c\x67\x20\142\x74\x6e\55\142\x6c\165\x65"], "\x6c\x61\142\x65\154" => "\103\162\145\x61\164\145"]); goto a18ae; cf2ff: $form = $this->createForm("\x41\x70\x70\x5c\x46\x6f\x72\x6d\x5c\x53\x69\164\x65\x4e\145\x77\120\x68\x70\124\171\x70\x65", [], ["\x61\x63\x74\x69\157\x6e" => $this->generateUrl("\143\154\x70\137\x73\151\x74\145\x5f\x70\x68\160\x5f\x6e\145\167"), "\155\145\164\150\157\x64" => "\120\x4f\123\124", "\x61\x74\x74\x72" => []]); goto Cae65; A0d69: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto fdf7c; fdf7c: if (true === $form->isValid()) { goto A69e7; } goto Bf23e; Bf23e: $this->formErrors = $this->getErrorMessages($form); goto Dc29a; c6bd3: A69e7: goto cc4cd; Dc29a: goto ff5cc; goto c6bd3; d0aae: ff5cc: goto B9907; cc4cd: try { goto dd7e1; B7f1b: $user = $this->getUser(); goto bfdf3; A69be: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto d561a; C97b7: $phpVersion = $form->get("\160\150\160\126\145\162\x73\x69\157\x6e")->getData(); goto A3e18; e4903: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto a578e; fb983: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto B6c00; } goto cfb72; E3ab4: goto b8e0c; goto bb4a9; D9c4b: $varnishCacheSettings = []; goto Bede1; D4c4f: $siteUserPassword = $form->get("\x73\x69\164\145\x55\x73\145\x72\120\141\x73\163\x77\157\x72\144")->getData(); goto ea67a; dd7e1: $session = $request->getSession(); goto B3a60; Ab6cd: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto B17f4; A3e18: $siteUser = $form->get("\x73\151\x74\145\125\x73\x65\162")->getData(); goto D4c4f; cfb72: $rootDirectory = sprintf("\45\x73\x2f\x25\163", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\57"), "\57")); goto bcef6; Ab779: return $response; goto E6788; c596c: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\163\x69\x74\145\x73")); goto Ab779; B17f4: A4295: goto e4903; bcef6: B6c00: goto D9c4b; bb4a9: E8b8f: goto B7f1b; d561a: $session->getFlashBag()->set("\163\x75\x63\143\145\x73\x73", $this->translator->trans("\123\x69\164\145\40\150\141\x73\40\142\x65\x65\x6e\x20\143\162\x65\141\164\145\144\x2e")); goto c596c; bfdf3: $rootDirectory = $domainName; goto fb983; E6788: b8e0c: goto eba4c; a578e: $eventData = ["\163\151\164\145" => $domainName, "\166\x68\157\163\x74\124\x65\155\x70\154\141\164\145\x4e\141\155\x65" => $vhostTemplateName, "\160\x68\160\126\145\x72\163\151\x6f\x6e" => $phpVersion, "\163\x69\164\x65\x55\163\145\162" => $siteUser]; goto A69be; B3a60: $vhostTemplateName = $form->get("\141\160\160\x6c\x69\x63\x61\164\x69\157\x6e")->getData(); goto a5ee0; ebaf8: throw new \Exception(sprintf("\x56\150\x6f\x73\164\x20\x74\x65\x6d\160\154\141\164\x65\40\x22\45\x73\42\x20\x6e\157\x74\x20\146\x6f\x75\156\x64\56", $vhostTemplateName)); goto E3ab4; a5ee0: $domainName = $form->get("\144\157\x6d\x61\x69\156\x4e\141\x6d\x65")->getData(); goto C97b7; Bede1: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto A4295; } goto Ab6cd; D8157: if (false === is_null($vhostTemplateEntity)) { goto E8b8f; } goto ebaf8; ea67a: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto D8157; eba4c: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\x6e\147\x65\x72", $this->translator->trans("\101\156\x20\145\x72\162\157\x72\x20\x68\141\x73\40\x6f\143\143\165\162\162\145\144\x2c\x20\x65\162\x72\x6f\x72\x20\155\x65\x73\x73\x61\147\145\x3a\x20\x25\145\162\162\157\162\x4d\x65\163\x73\141\147\x65\x25", ["\x25\x65\162\x72\157\x72\x4d\145\x73\x73\x61\147\x65\x25" => $e->getMessage()])); } goto d0aae; B9907: } public function newWordPressSite(Request $request) : Response { goto E8af6; e3ea5: if (!(false === is_null($response))) { goto Ad312; } goto A03a2; f4fdc: $response = $this->redirect($this->generateUrl("\143\154\x70\137\163\151\x74\x65\163")); goto bb7d0; E8af6: $hasPermissions = $this->hasPermissions(); goto C4668; A1424: e90e0: goto Eaaaf; bb7d0: goto F46b0; goto ffe86; d91df: if (!(true === $request->isMethod("\x50\117\x53\124"))) { goto e90e0; } goto a50cf; C4668: if (true === $hasPermissions) { goto F5af9; } goto f4fdc; B4be9: if (!(true === $form->isSubmitted())) { goto C8f3a; } goto A5953; df194: Ad312: goto e9350; F7b9f: F46b0: goto Bb65e; A03a2: return $response; goto df194; e9350: C8f3a: goto A1424; Eaaaf: $response = $this->render("\106\x72\157\156\164\x65\156\x64\x2f\123\151\x74\x65\x2f\x4e\145\x77\57\x77\157\162\x64\x70\x72\145\163\163\56\x68\164\155\154\x2e\164\x77\151\x67", ["\165\x73\x65\x72" => $user, "\146\x6f\162\155" => $form->createView(), "\x66\x6f\x72\x6d\x45\x72\162\157\x72\x73" => $this->formErrors]); goto F7b9f; ffd9d: $form = $this->createWordPressSiteForm(); goto d91df; Bb65e: return $response; goto aa03b; ffe86: F5af9: goto ab6ad; a50cf: $form->handleRequest($request); goto B4be9; A5953: $response = $this->handleCreateWordPressSiteForm($request, $form); goto e3ea5; ab6ad: $user = $this->getUser(); goto ffd9d; aa03b: } private function createWordPressSiteForm() : Form { goto e1f0d; f93a6: $form->add("\163\165\x62\x6d\x69\x74", SubmitType::class, ["\x61\164\x74\x72" => ["\143\154\141\163\163" => "\x62\x74\x6e\x20\x62\x74\156\x2d\154\147\40\142\x74\x6e\x2d\x62\154\165\x65"], "\x6c\141\x62\145\x6c" => "\103\x72\x65\141\164\x65"]); goto b7700; e1f0d: $form = $this->createForm("\x41\160\160\134\x46\157\162\x6d\134\x53\x69\164\x65\x4e\x65\x77\127\x6f\162\144\x50\162\x65\x73\x73\124\171\160\x65", [], ["\x61\x63\164\x69\x6f\156" => $this->generateUrl("\143\154\160\x5f\x73\x69\x74\145\x5f\167\x6f\x72\x64\160\x72\x65\163\163\x5f\x6e\145\167"), "\155\x65\164\150\x6f\144" => "\x50\x4f\x53\124", "\x61\x74\x74\x72" => ["\x69\144" => "\x6e\145\167\x2d\x77\157\162\x64\160\162\x65\x73\163\55\x73\x69\164\x65\55\146\157\x72\155"]]); goto f93a6; b7700: return $form; goto Ffdd3; Ffdd3: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto E4c35; d7689: c9692: goto Fa505; C1cf9: goto c9692; goto b4024; b4024: d9169: goto A170c; E4c35: if (true === $form->isValid()) { goto d9169; } goto B1f35; A170c: try { goto cb119; d38a1: $siteCredentials[$this->translator->trans("\x44\141\164\x61\142\141\163\x65")] = [$this->translator->trans("\x48\157\x73\164") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\120\x6f\162\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\104\141\x74\x61\142\141\x73\x65\x20\x4e\x61\155\145") => $databaseName, $this->translator->trans("\x44\141\164\141\142\141\163\x65\x20\x55\163\145\x72\40\116\x61\x6d\x65") => $databaseUserName, $this->translator->trans("\x44\141\164\x61\142\x61\163\145\x20\x55\163\x65\162\40\120\141\x73\163\167\157\x72\144") => $databaseUserPassword]; goto Dfc9e; cbdf8: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto Bf87b; c2350: return $response; goto be87b; Ebada: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto cbdf8; d8098: $adminPassword = $form->get("\x61\144\x6d\x69\156\x50\141\163\x73\x77\157\x72\x64")->getData(); goto edd06; A4c23: $domainName = $form->get("\x64\157\x6d\x61\151\x6e\116\x61\x6d\x65")->getData(); goto b772c; edd06: $adminEmail = $form->get("\141\x64\x6d\151\156\x45\x6d\141\x69\154")->getData(); goto F500a; dcb2f: $session->set("\163\x69\164\145\x43\x72\145\144\x65\x6e\x74\151\x61\154\x73", $siteCredentials); goto a7de9; B4ca7: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto D13ea; } goto Abb14; D5ac3: $url = sprintf("\150\164\164\160\163\72\57\57\x25\x73", $siteEntity->getDomainName()); goto Fc7d9; B1ce1: $siteUser = $form->get("\163\x69\x74\x65\x55\163\145\162")->getData(); goto b8ef4; Dfc9e: $siteCredentials["\x57\157\x72\x64\x50\x72\x65\x73\163"] = [$this->translator->trans("\x41\144\155\x69\156\x20\105\55\x4d\141\x69\154") => $adminEmail, $this->translator->trans("\101\x64\155\151\156\40\x55\163\145\x72\x20\116\x61\x6d\x65") => $adminUserName, $this->translator->trans("\101\x64\155\x69\156\40\120\141\x73\163\167\x6f\162\x64") => $adminPassword, $this->translator->trans("\x41\x64\x6d\x69\156\x20\125\x72\154") => sprintf("\x68\164\164\160\163\x3a\x2f\57\45\163\57\167\160\55\x61\144\x6d\151\156\x2f", rtrim($domainName, "\x2f"))]; goto A4f9a; a7de9: $eventData = ["\x73\151\164\x65" => $domainName, "\x73\x69\164\145\x55\x73\145\162" => $siteUser]; goto A0ba0; b772c: $generatedName = $this->generateNameFromDomainName($domainName); goto B1ce1; b7fc9: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto B31fc; a1a58: D13ea: goto bb91a; bb91a: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto E9d00; A3050: $databaseEntity = $this->databaseEntityManager->createEntity(); goto F710f; f7717: $databaseEntity->addUser($databaseUserEntity); goto E93ee; D3bdf: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto a6aea; E9d00: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Ed306; Db89a: $this->siteEntityManager->updateEntity($siteEntity); goto b71a0; a6aea: $databaseUserEntity->setUserName($databaseUserName); goto b7fc9; da27a: $databaseName = $this->getUniqueDatabaseName($generatedName); goto Fb5ae; Bf87b: $varnishCacheSettings = []; goto B4ca7; Fb5ae: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto B324f; F7b65: $adminUserName = $form->get("\141\144\155\151\156\125\x73\x65\162\116\141\x6d\x65")->getData(); goto d8098; F9b1f: $databaseManager->createDatabase($databaseEntity); goto Fa76b; A0ba0: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto a26b8; Fa76b: $databaseManager->createUser($databaseUserEntity); goto Db89a; b8ef4: $siteUserPassword = $form->get("\163\x69\164\x65\x55\163\x65\x72\120\141\x73\x73\x77\x6f\x72\x64")->getData(); goto Ebada; E00d2: $databaseEntity->setSite($siteEntity); goto D3bdf; Ed306: $instance = $request->attributes->get("\x69\156\x73\x74\x61\x6e\x63\145"); goto Ecd1e; B31fc: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto Df381; e9d64: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto F9b1f; De347: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto A3050; E93ee: $siteEntity->addDatabase($databaseEntity); goto e9d64; B324f: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto D5ac3; F500a: $isMultiSite = $form->get("\155\x75\x6c\164\x69\123\x69\x74\145")->getData(); goto De347; F710f: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto b3548; b71a0: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto d38a1; A4f9a: A6c15: goto dcb2f; Fc7d9: $title = $form->get("\x73\151\x74\145\x54\151\x74\154\x65")->getData(); goto F7b65; b3548: $databaseEntity->setName($databaseName); goto E00d2; a26b8: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\x73\151\164\x65\x5f\x77\157\162\x64\x70\162\x65\163\x73\x5f\x69\156\x73\x74\x61\x6c\x6c\145\144")); goto c2350; E7aeb: if (!(false === is_null($siteEntity))) { goto A6c15; } goto da27a; cb119: $user = $this->getUser(); goto C9925; C9925: $session = $request->getSession(); goto A4c23; Ecd1e: $siteCredentials = [$this->translator->trans("\x53\151\164\145") => [$this->translator->trans("\x49\120\40\x41\144\x64\162\145\x73\163") => $instance->getIpv4PublicIp(), $this->translator->trans("\x44\157\x6d\x61\x69\x6e\40\116\141\x6d\x65") => sprintf("\150\x74\x74\160\x73\x3a\57\x2f\x25\163", $domainName), $this->translator->trans("\x53\151\x74\x65\x20\x55\163\x65\x72") => $siteUser, $this->translator->trans("\120\141\163\x73\167\157\162\144") => $siteUserPassword]]; goto E7aeb; Abb14: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto a1a58; Df381: $databaseUserEntity->setDatabase($databaseEntity); goto f7717; be87b: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\147\x65\162", $this->translator->trans("\x41\x6e\40\145\162\x72\x6f\x72\x20\150\x61\163\40\x6f\x63\143\x75\x72\162\145\x64\54\40\x65\162\x72\x6f\x72\40\155\145\x73\x73\x61\147\x65\72\x20\45\145\x72\x72\x6f\x72\x4d\x65\x73\163\x61\x67\145\45", ["\x25\x65\x72\x72\157\162\x4d\x65\x73\x73\141\147\145\x25" => $e->getMessage()])); } goto d7689; B1f35: $this->formErrors = $this->getErrorMessages($form); goto C1cf9; Fa505: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto c2818; Cad28: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto F9059; Ea40c: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\x61\x6c\x75\x65"], $config["\x72\x61\x77"]); C5137: } goto b3168; F9059: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\x61\x6c\165\145"], $config["\x72\141\x77"]); Ac1bd: } goto Bf58c; e0dc9: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto Ebc01; E0b6c: $this->wordPressMultiSiteConfigValues["\104\x4f\x4d\101\x49\116\137\103\x55\122\x52\x45\x4e\124\137\123\111\x54\x45"]["\166\x61\154\x75\145"] = $siteEntity->getDomainName(); goto Ea40c; c2b17: $wordPressInstaller->resetPermissions(); goto F6c5f; A3d87: $databaseName = $databaseEntity->getName(); goto D8358; Ddf07: $wordPressInstaller->downloadAndExtractLatestVersion(); goto ce2d8; Bf433: if (!(true === $isMultiSite)) { goto a0105; } goto E0b6c; b3168: d824a: goto E1d0c; ce2d8: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto Cad28; c2818: $databaseHost = sprintf("\x25\163\72\x25\x73", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto A3d87; E1d0c: a0105: goto c2b17; Bf58c: D23fb: goto Bf433; D8358: $databaseUserName = $databaseUserEntity->getUserName(); goto e0dc9; Ebc01: $wordPressInstaller = new WordPressInstaller($siteEntity); goto Ddf07; F6c5f: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto Fa2a0; A79f2: $subjectAlternativeNames[] = $registrableDomain; goto A2b94; E1fbf: if (!(false === empty($redirectionVhostTemplate))) { goto Ae278; } goto db953; Cb66b: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto dac13; b1a05: $phpSiteCreator->createRootDirectory(); goto E7dda; Eeaab: $siteEntity->setDomainName($domainName); goto A60e6; Edb97: if (!(false === is_null($subdomain) && "\x77\167\167" == $subdomain)) { goto bab67; } goto A79f2; B79c1: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto E9360; B4df8: $siteEntity->setPhpSettings($phpSettingsEntity); goto F6d00; d56b2: ca4d4: goto b57d2; A808f: $phpSite->setRegistrableDomain($registrableDomain); goto B984b; Fa2a0: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto Cf084; dac13: $phpSite->setCertificate($certificateEntity); goto b912d; a3280: $phpSiteCreator->createIndexPhp(); goto dae18; cc7ef: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto E7c70; Ce27b: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto B0a95; Cd69d: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto E0c4d; A1960: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Fa204; D0a8c: a9268: goto Edb97; A16be: $subjectAlternativeNames[] = sprintf("\167\167\x77\56\x25\x73", $domainName); goto D0a8c; F9f83: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto Ec287; E5d9f: if (!(true === $varnishCache)) { goto E6fc0; } goto A435c; db35e: return $siteEntity; goto d0e04; c133a: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto f8a84; fdd4f: if (true === isset($_ENV["\x41\x50\120\x5f\110\x54\x54\120\x33"]) && "\x74\162\x75\x65" === $_ENV["\101\x50\x50\137\110\124\124\120\63"]) { goto C1c00; } goto ed558; Ec287: E6fc0: goto C4c51; A435c: $phpSite->setVarnishCache(true); goto afe98; D8823: $vhostTemplate->resetProcessors(); goto D9f8d; F8ad8: $siteEntity->setType(SiteEntity::TYPE_PHP); goto Eeaab; E0c4d: $siteEntity = $this->siteEntityManager->createEntity(); goto F8ad8; b57d2: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto E1fbf; b133e: $siteEntity->setRootDirectory($rootDirectory); goto B52b9; B984b: $phpSite->setSubdomain($subdomain); goto Cb66b; A66d2: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto Bd949; ecb38: $certificateEntity->setDefaultCertificate(true); goto a24e3; F961d: $phpSiteCreator->reloadNginxService(); goto D11f2; bd25a: $phpSiteCreator->createUser(); goto b1a05; a24e3: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto F47e4; f567d: $siteEntity->setVhostTemplate($vhostTemplate); goto Fccae; F618b: c61ac: goto f567d; e905d: $csr = $csrGenerator->generate(); goto D6a8e; B0a95: $subdomain = $resolvedDomainName->subDomain()->toString(); goto B0b19; e00ba: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto b7835; } goto Cb300; Ea105: $phpSiteCreator->reloadPhpFpmService(); goto E5d9f; db953: $vhostTemplate = sprintf("\x25\x73\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto Bd77d; b912d: $phpSite->setPhpSettings($phpSettingsEntity); goto c133a; A2b94: bab67: goto fd61e; b4294: $phpSite->setUser($siteEntity->getUser()); goto B79c1; cf567: $constraintViolationList->addAll($phpSettingsConstraints); goto e8af5; E94e8: if (!(true === is_null($subdomain))) { goto a9268; } goto A16be; ed558: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\x2e\56\57\x2e\56\x2f\x72\x65\x73\x6f\x75\162\x63\145\x73\57\x6e\147\x69\156\x78\x2f\166\150\157\163\164\137\164\x65\155\160\x6c\x61\164\145\x2f\162\x65\x64\x69\162\145\143\164"); goto Cf31a; a800a: $rsaKeyGenerator = new RsaKeyGenerator(); goto D09e1; dae18: $phpSiteCreator->createPrivateKeyAndCertificate(); goto Cec4a; Cf0c2: $phpSite = new PhpSite(); goto b4294; A60e6: $siteEntity->setUser($siteUser); goto F98a4; E9f3b: $vhostTemplate = new PhpVhostTemplate($phpSite); goto Af6c0; F6d00: $phpSettingsEntity->setPhpVersion($phpVersion); goto Bb182; Cf084: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\x2f")), "\57"); goto a76a6; Bb182: $phpSettingsEntity->setSite($siteEntity); goto B4e85; f8a84: $phpSiteCreator = new PhpSiteCreator($phpSite); goto bd25a; Cb300: $constraintViolationList = new ConstraintViolationList(); goto b6ad4; E7dda: $phpSiteCreator->createLogrotateFile(); goto a3280; E7c70: $certificateEntity->setCertificate($selfSignedCertificate); goto Ccc7e; B13b8: throw new \Exception(implode("\73\x20", $errorMessages)); goto Ad77f; Cec4a: $phpSiteCreator->createPhpFpmPool(); goto Ea105; D11f2: $phpSiteCreator->resetPermissions(); goto E9f3b; Dbb19: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto c61ac; } goto fdd4f; Fccae: $phpSettingsEntity = new PhpSettingsEntity(); goto B4df8; D3a2b: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto ef6f6; e8af5: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto B13b8; d58b7: C1c00: goto Bf996; Cf31a: goto ca4d4; goto d58b7; B4e85: $siteConstraints = $this->validator->validate($siteEntity); goto f9fbd; Ff34c: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Cd69d; Fa204: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E8443; D6a8e: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto ecb38; Ad77f: b7835: goto a149e; B542e: $vhostTemplate->build(); goto A1960; f9fbd: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto e00ba; F98a4: $siteEntity->setUserPassword($siteUserPassword); goto b133e; B52b9: if (!(false === empty($varnishCache))) { goto a16fd; } goto C3c4e; b6ad4: $constraintViolationList->addAll($siteConstraints); goto cf567; ef6f6: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto B542e; Bd77d: Ae278: goto F618b; E9360: $phpSite->setDomainName($domainName); goto A808f; A974f: $subjectAlternativeNames = []; goto E94e8; Af6c0: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto D8823; B0b19: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Ff34c; fd61e: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto E3796; E3796: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto e905d; F47e4: $certificateEntity->setCsr($csr); goto cc7ef; Bd949: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto F9f83; a149e: $certificateEntity = $this->certificateEntityManager->createEntity(); goto cd998; D9f8d: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto D3a2b; afe98: $defaultVarnishCacheSettings = ["\145\156\x61\x62\154\145\x64" => false, "\163\145\162\x76\x65\162" => self::VARNISH_CACHE_SERVER, "\x63\x61\x63\150\x65\124\x61\147\120\x72\x65\x66\x69\170" => substr(md5(time()), 0, 4)]; goto A66d2; E1cbe: a16fd: goto Dbb19; cd998: $certificateEntity->setSite($siteEntity); goto a800a; E8443: $this->siteEntityManager->updateEntity($siteEntity); goto db35e; Bf996: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\x2f\56\x2e\57\x2e\56\x2f\162\x65\163\x6f\x75\x72\143\145\163\x2f\156\x67\151\x6e\170\57\x76\x68\157\163\x74\137\x74\145\x6d\x70\154\x61\x74\x65\57\x72\x65\144\x69\162\x65\x63\164\x2d\150\x74\164\160\x33"); goto d56b2; Ccc7e: $siteEntity->setCertificate($certificateEntity); goto Cf0c2; C4c51: $phpSiteCreator->createNginxVhost(); goto F961d; C3c4e: $siteEntity->setVarnishCache(true); goto E1cbe; a76a6: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Ce27b; D09e1: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto A974f; d0e04: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto e287f; b9409: $csr = $csrGenerator->generate(); goto bcb1d; cc86e: $siteEntity = $this->siteEntityManager->createEntity(); goto ae3a9; Df3fa: if (!(true === is_null($subdomain) || "\167\x77\167" == $subdomain)) { goto Bbf76; } goto ba094; ff1c0: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto f59d0; a3238: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto c24fd; E9b61: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto Ad26e; } goto Bbea9; b627d: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto A420f; F598e: $siteEntity->setUser($siteUser); goto f99aa; D1466: $certificateEntity->setCertificate($selfSignedCertificate); goto Ba73a; f8480: $nodejsSiteCreator->reloadNginxService(); goto b0e5d; d88d4: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto f9e0a; D5f03: $vhostTemplate->build(); goto E7dcb; ffc6e: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto E9b61; b0e5d: $nodejsSiteCreator->resetPermissions(); goto D7688; E8d53: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto Fb8d9; Fb8d9: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Dc2e5; d9b4d: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto Ee178; E85b2: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Ccd8e; a5672: $nodejsSite->setRegistrableDomain($registrableDomain); goto Fbe20; bcb1d: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto c19ad; Add5c: $subjectAlternativeNames[] = $registrableDomain; goto C4adb; Bbea9: $constraintViolationList = new ConstraintViolationList(); goto a1e0d; B2e3c: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto F35e1; B42de: $nodejsSite->setUser($siteEntity->getUser()); goto C9b40; D78c9: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto b9409; cafd3: $nodejsSiteCreator->installNodejs(); goto dff3a; D7595: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Ba947; E95f4: $nodejsSite = new NodejsSite(); goto B42de; F35e1: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto ff798; F0287: $this->siteEntityManager->updateEntity($siteEntity); goto d9d5a; Fce2d: $nodejsSettingsEntity->setSite($siteEntity); goto a2642; Ccd8e: $certificateEntity->setSite($siteEntity); goto Aaa76; E7dcb: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto C991e; Fd290: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto D1466; dab1c: C2afd: goto a9041; D8f9d: $certificateEntity->setCsr($csr); goto Fd290; D7688: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto D7595; ad929: $subjectAlternativeNames = []; goto B3067; b3ce4: if (!(false === empty($redirectionVhostTemplate))) { goto Af723; } goto F2eaa; dfa70: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto D78c9; c708d: $siteEntity->setDomainName($domainName); goto F598e; Dc2e5: $subdomain = false === empty($subdomain) ? $subdomain : null; goto d9b4d; F7535: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto B2e3c; F485b: $constraintViolationList->addAll($nodejsSettingsConstraints); goto d88d4; Bb790: if (!(false === is_null($subdomain) && "\167\x77\x77" == $subdomain)) { goto A6280; } goto Add5c; ba094: if (true === isset($_ENV["\101\120\120\x5f\x48\124\x54\x50\x33"]) && "\164\162\165\x65" === $_ENV["\101\x50\x50\137\x48\124\124\120\x33"]) { goto b681d; } goto c19a3; B3067: if (!(true === is_null($subdomain))) { goto a14e1; } goto bf663; dff3a: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto d6356; A420f: $nodejsSiteCreator->createUser(); goto Bfefe; ae3a9: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto c708d; Ba73a: $siteEntity->setCertificate($certificateEntity); goto E95f4; F2eaa: $vhostTemplate = sprintf("\x25\x73\45\163", $redirectionVhostTemplate, $vhostTemplate); goto a6f5b; C9b40: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto Dd834; e287f: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto E8d53; f99aa: $siteEntity->setUserPassword($siteUserPassword); goto c5ebe; c19a3: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\x2f\x2e\56\57\56\56\57\162\x65\x73\157\x75\162\143\145\x73\x2f\156\x67\151\x6e\170\57\x76\150\157\163\x74\137\x74\145\x6d\x70\154\x61\x74\145\x2f\162\145\144\x69\162\x65\x63\x74"); goto f559e; ff798: $nodejsSettingsEntity->setPort($port); goto Fce2d; c5ebe: $siteEntity->setRootDirectory($domainName); goto Df3fa; d9d5a: return $siteEntity; goto A3766; Be267: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto ff1c0; f59d0: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto D5f03; bf423: $nodejsSiteCreator->createLogrotateFile(); goto c83f4; a1e0d: $constraintViolationList->addAll($siteConstraints); goto F485b; a6f5b: Af723: goto bf237; Ee178: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto cc86e; Bfefe: $nodejsSiteCreator->createRootDirectory(); goto bf423; Fbe20: $nodejsSite->setSubdomain($subdomain); goto Be2e8; fb621: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto D8f9d; c83f4: $nodejsSiteCreator->createNvmDirectory(); goto cafd3; C4adb: A6280: goto dfa70; dd0f6: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\57\56\x2e\x2f\56\x2e\57\x72\x65\x73\157\x75\162\x63\x65\x73\x2f\156\147\x69\x6e\170\57\x76\x68\x6f\163\164\137\164\145\155\160\x6c\x61\x74\145\x2f\x72\145\144\151\162\145\143\164\55\150\164\x74\x70\63"); goto dab1c; d6356: $nodejsSiteCreator->createNginxVhost(); goto f8480; d2988: b681d: goto dd0f6; a9041: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto b3ce4; e152a: Ad26e: goto E85b2; E2d26: $siteEntity->setVhostTemplate($vhostTemplate); goto F7535; c24fd: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto b627d; Dd834: $nodejsSite->setDomainName($domainName); goto a5672; c1ec6: $nodejsSite->setCertificate($certificateEntity); goto a3238; a2642: $siteConstraints = $this->validator->validate($siteEntity); goto ffc6e; bf663: $subjectAlternativeNames[] = sprintf("\167\x77\x77\56\x25\x73", $domainName); goto a1521; bf237: Bbf76: goto E2d26; Be2e8: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto c1ec6; c19ad: $certificateEntity->setDefaultCertificate(true); goto fb621; Aaa76: $rsaKeyGenerator = new RsaKeyGenerator(); goto D6500; C991e: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto F0287; f559e: goto C2afd; goto d2988; D6500: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto ad929; f9e0a: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto e152a; a1521: a14e1: goto Bb790; Ba947: $vhostTemplate->resetProcessors(); goto Be267; A3766: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto ff58b; A198f: return $siteEntity; goto Db371; ebd85: if (!(false === empty($redirectionVhostTemplate))) { goto bb987; } goto ab748; Bf65e: $pythonSettingsEntity = new PythonSettingsEntity(); goto C28c6; Fd953: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto E0c88; acfaf: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto b89d3; c945c: $constraintViolationList = new ConstraintViolationList(); goto B8558; a5fe6: $rsaKeyGenerator = new RsaKeyGenerator(); goto D2cc1; c4132: ba736: goto Fa0a0; Cc3ab: $pythonSiteCreator->resetPermissions(); goto f9f8c; Eccef: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto B9175; fe754: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto D1d6e; } goto c945c; Cc0c1: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto a8d38; E0017: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Bb465; Fd02c: $pythonSite->setUser($siteEntity->getUser()); goto afaeb; B3657: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto Ad3ac; B8558: $constraintViolationList->addAll($siteConstraints); goto dc134; e60d4: if (!(true === is_null($subdomain))) { goto A6dfd; } goto Cd380; D3689: f2e3d: goto c9b9f; bf018: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto f2e3d; } goto Dd880; b4ccd: $pythonSite = new PythonSite(); goto Fd02c; Ce2a8: bb987: goto D3689; E29c9: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Dc0fc; b0787: $pythonSite->setCertificate($certificateEntity); goto Cf8be; e2a41: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto D98a9; B8aea: $siteConstraints = $this->validator->validate($siteEntity); goto D09a8; dc43b: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto A5a4a; F0d6e: $certificateEntity->setCertificate($selfSignedCertificate); goto D22a1; B729c: $siteEntity->setDomainName($domainName); goto ec5da; a8d38: $pythonSiteCreator->createUser(); goto E09d7; D98a9: $pythonSettingsEntity->setPort($port); goto e035c; dc134: $constraintViolationList->addAll($pythonSettingsConstraints); goto acfaf; c9b9f: $siteEntity->setVhostTemplate($vhostTemplate); goto Bf65e; e519b: A6dfd: goto d398f; c2984: $pythonSite->setSubdomain($subdomain); goto adb48; cdc7d: $pythonSiteCreator->writePythonVersionFile(); goto Eccef; Cf8be: $pythonSite->setPythonSettings($pythonSettingsEntity); goto e3350; C82c4: $certificateEntity->setDefaultCertificate(true); goto A756f; d3a02: $pythonSiteCreator->createLogrotateFile(); goto cdc7d; E32d6: $this->siteEntityManager->updateEntity($siteEntity); goto Ab781; adb48: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto b0787; ad586: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\x2e\56\x2f\56\56\57\x72\x65\x73\x6f\165\162\x63\145\x73\57\156\x67\151\156\170\x2f\x76\150\x6f\x73\x74\137\x74\x65\x6d\160\154\141\x74\x65\57\x72\x65\144\x69\162\145\x63\164\55\150\164\164\x70\x33"); goto c4132; f2f3b: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\56\56\x2f\56\x2e\57\x72\x65\163\x6f\165\x72\143\x65\x73\x2f\156\147\151\x6e\170\x2f\x76\150\x6f\x73\164\137\164\x65\155\x70\x6c\x61\x74\x65\57\162\145\x64\151\162\145\143\x74"); goto f91f0; D0ffb: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto C82c4; D09a8: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto fe754; b920f: $siteEntity->setUserPassword($siteUserPassword); goto A31c7; Bb465: $certificateEntity->setSite($siteEntity); goto a5fe6; e3350: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Cc0c1; D2cc1: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Ccee4; Fa0a0: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto ebd85; Dcd67: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto F0d6e; ba638: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto e9084; a10f7: $pythonSite->setDomainName($domainName); goto b7855; Dce5f: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Fd953; Bafa3: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto E29c9; f91f0: goto ba736; goto C5d69; A31c7: $siteEntity->setRootDirectory($domainName); goto bf018; b7855: $pythonSite->setRegistrableDomain($registrableDomain); goto c2984; a2f4c: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto a8f9c; A5a4a: $vhostTemplate->build(); goto cafb1; ec5da: $siteEntity->setUser($siteUser); goto b920f; afaeb: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto a10f7; cafb1: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto E32d6; ab748: $vhostTemplate = sprintf("\45\x73\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto Ce2a8; E5e43: $pythonSiteCreator->reloadNginxService(); goto Cc3ab; Bc75f: D1d6e: goto E0017; f9f8c: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto a2f4c; Ad3ac: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Dce5f; b89d3: throw new \Exception(implode("\x3b\40", $errorMessages)); goto Bc75f; B9175: $pythonSiteCreator->createNginxVhost(); goto E5e43; Ccee4: $subjectAlternativeNames = []; goto e60d4; Ab781: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto A198f; D29d5: $subjectAlternativeNames[] = $registrableDomain; goto Fa852; a8f9c: $vhostTemplate->resetProcessors(); goto ba638; E09d7: $pythonSiteCreator->createRootDirectory(); goto d3a02; Dd880: if (true === isset($_ENV["\x41\x50\120\137\x48\124\124\120\63"]) && "\164\x72\165\x65" === $_ENV["\x41\x50\x50\x5f\x48\x54\124\120\63"]) { goto F20d5; } goto f2f3b; E0c88: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto cd48c; ff58b: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto B3657; C28c6: $siteEntity->setPythonSettings($pythonSettingsEntity); goto e2a41; D22a1: $siteEntity->setCertificate($certificateEntity); goto b4ccd; Cd380: $subjectAlternativeNames[] = sprintf("\167\x77\167\56\x25\163", $domainName); goto e519b; d398f: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto c8a2d; } goto D29d5; A756f: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto A92b2; A92b2: $certificateEntity->setCsr($csr); goto Dcd67; Dc0fc: $csr = $csrGenerator->generate(); goto D0ffb; f29fb: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto B729c; C5d69: F20d5: goto ad586; cd48c: $siteEntity = $this->siteEntityManager->createEntity(); goto f29fb; Fa852: c8a2d: goto Bafa3; e035c: $pythonSettingsEntity->setSite($siteEntity); goto B8aea; e9084: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto dc43b; Db371: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto F9035; f955f: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto e74b9; b4aab: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto c05f0; bde2f: $certificateEntity->setCsr($csr); goto B337c; Ba9af: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto e8d35; b4c00: $constraintViolationList->addAll($siteConstraints); goto D5632; D3121: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto fd8a3; Dc7c0: $siteConstraints = $this->validator->validate($siteEntity); goto E0678; Da8be: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto fbb70; B8b5f: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto B0610; e8d35: $csr = $csrGenerator->generate(); goto e6d83; C4d23: $siteEntity = $this->siteEntityManager->createEntity(); goto c3bc5; B1780: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto e3085; C8dda: $subdomain = $resolvedDomainName->subDomain()->toString(); goto E83ce; E0678: if (!count($siteConstraints)) { goto B6538; } goto Da577; a5187: $staticSite->setUser($siteEntity->getUser()); goto Bb316; b3302: A1325: goto Da8be; e6d83: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Df21f; fbdfa: goto A1325; goto ca19f; e3085: $staticSiteCreator = new StaticSiteCreator($staticSite); goto B3f76; f2c1f: B6538: goto A0cf1; eabc5: $staticSiteCreator->createRootDirectory(); goto Ac163; F441e: $staticSite->setCertificate($certificateEntity); goto B1780; A0cf1: $certificateEntity = $this->certificateEntityManager->createEntity(); goto c79cf; B12cf: $vhostTemplate->build(); goto fb85e; f0d5a: $staticSite->setDomainName($domainName); goto Ed580; Ed580: $staticSite->setRegistrableDomain($registrableDomain); goto e8498; e5235: throw new \Exception(implode("\x3b\40", $errorMessages)); goto f2c1f; Fd885: A2732: goto Df641; fd8a3: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto a055d; Df3bc: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto C8dda; D8d88: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto F441e; B337c: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto ba969; d9c5d: return $siteEntity; goto e1709; c05f0: $subjectAlternativeNames = []; goto d9af6; ba969: $certificateEntity->setCertificate($selfSignedCertificate); goto e76b6; dc049: $staticSiteCreator->reloadNginxService(); goto d0f2a; ecfaa: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto D19a2; c977d: $staticSiteCreator->createPrivateKeyAndCertificate(); goto Eb621; d9af6: if (!(true === is_null($subdomain))) { goto cef1b; } goto E5853; ca19f: b617c: goto F9dcc; c269b: $siteEntity->setUser($siteUser); goto d702b; beb63: Fb3fa: goto e03b1; e8498: $staticSite->setSubdomain($subdomain); goto D8d88; ff216: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\x2f\x2e\56\57\56\x2e\57\162\x65\x73\157\x75\162\x63\x65\x73\x2f\x6e\x67\x69\x6e\x78\57\x76\150\x6f\x73\164\x5f\x74\145\155\160\154\x61\164\145\57\162\145\x64\151\162\145\143\164"); goto fbdfa; Fb571: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto bde2f; c79cf: $certificateEntity->setSite($siteEntity); goto D2d77; d702b: $siteEntity->setUserPassword($siteUserPassword); goto c09fb; Df641: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Ba9af; B0610: $this->siteEntityManager->updateEntity($siteEntity); goto d9c5d; F9035: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Df3bc; D2d77: $rsaKeyGenerator = new RsaKeyGenerator(); goto b4aab; Ac163: $staticSiteCreator->createLogrotateFile(); goto B3d48; C8175: $siteEntity->setDomainName($domainName); goto c269b; D7d93: if (!(false === is_null($subdomain) && "\x77\167\x77" == $subdomain)) { goto A2732; } goto Bc334; Bb316: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto f0d5a; e76b6: $siteEntity->setCertificate($certificateEntity); goto Cf4b3; fb85e: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto B8b5f; Eb621: $staticSiteCreator->createNginxVhost(); goto dc049; a445e: $vhostTemplate = new StaticVhostTemplate($staticSite); goto f955f; Df21f: $certificateEntity->setDefaultCertificate(true); goto Fb571; F9dcc: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\56\56\57\56\x2e\57\x72\145\163\157\165\162\x63\145\163\x2f\x6e\x67\151\x6e\170\x2f\166\x68\157\x73\x74\x5f\x74\x65\x6d\160\154\141\164\x65\x2f\x72\145\x64\x69\162\145\x63\x74\55\150\x74\x74\160\63"); goto b3302; d0f2a: $staticSiteCreator->resetPermissions(); goto a445e; C80ee: cef1b: goto D7d93; Cf4b3: $staticSite = new StaticSite(); goto a5187; B3d48: $staticSiteCreator->createIndexHtml(); goto c977d; Cd16e: if (!(true === is_null($subdomain) || "\167\167\167" == $subdomain)) { goto E72d4; } goto Bd845; Bc334: $subjectAlternativeNames[] = $registrableDomain; goto Fd885; B3f76: $staticSiteCreator->createUser(); goto eabc5; E83ce: $subdomain = false === empty($subdomain) ? $subdomain : null; goto ecfaa; c09fb: $siteEntity->setRootDirectory($domainName); goto Cd16e; Da577: $constraintViolationList = new ConstraintViolationList(); goto b4c00; c3bc5: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto C8175; D19a2: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto C4d23; e03b1: E72d4: goto F09d4; fbb70: if (!(false === empty($redirectionVhostTemplate))) { goto Fb3fa; } goto E1d64; a055d: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto B12cf; Bd845: if (true === isset($_ENV["\101\x50\120\137\x48\124\124\120\x33"]) && "\x74\162\165\x65" === $_ENV["\101\x50\120\x5f\x48\124\x54\x50\63"]) { goto b617c; } goto ff216; e74b9: $vhostTemplate->resetProcessors(); goto D3121; D5632: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto e5235; E1d64: $vhostTemplate = sprintf("\x25\163\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto beb63; F09d4: $siteEntity->setVhostTemplate($vhostTemplate); goto Dc7c0; E5853: $subjectAlternativeNames[] = sprintf("\167\167\167\x2e\x25\x73", $domainName); goto C80ee; e1709: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto df018; B8328: $reversProxySiteCreator->resetPermissions(); goto e4562; b7890: $certificateEntity->setSite($siteEntity); goto A9880; A2718: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto dc7af; Cd53c: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto A02e5; Bacd1: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto a9908; } goto ab577; Cbea9: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto D9c7f; b3853: $reverseProxySite = new ReverseProxySite(); goto fc2e6; fc2e6: $reverseProxySite->setUser($siteEntity->getUser()); goto A45ae; f644c: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto edd67; B207f: $certificateEntity = $this->certificateEntityManager->createEntity(); goto b7890; d6670: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E7305; De886: $siteConstraints = $this->validator->validate($siteEntity); goto E76a2; E76a2: if (!count($siteConstraints)) { goto d78ec; } goto E7efa; E38ed: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto e66ef; A45ae: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto a630b; e66ef: $reverseProxySite->setCertificate($certificateEntity); goto Eefa1; f117a: $reversProxySiteCreator->createNginxVhost(); goto F41bf; Fd874: $siteEntity->setUser($siteUser); goto e6ffe; C4061: $siteEntity = $this->siteEntityManager->createEntity(); goto Cd53c; ab577: if (true === isset($_ENV["\x41\120\x50\137\x48\x54\124\120\63"]) && "\x74\162\x75\x65" === $_ENV["\x41\120\x50\x5f\x48\124\124\120\63"]) { goto b01ac; } goto C6106; Ca1e2: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto d7b99; deac5: $subdomain = $resolvedDomainName->subDomain()->toString(); goto D9693; e8df9: $subjectAlternativeNames = []; goto dacda; b1db8: $constraintViolationList->addAll($siteConstraints); goto B3df8; Bcbe3: if (!(false === is_null($subdomain) && "\167\x77\x77" == $subdomain)) { goto Cd33c; } goto f7ba4; d7b99: $vhostTemplate->resetProcessors(); goto D68ab; e6ffe: $siteEntity->setUserPassword($siteUserPassword); goto ca56c; aa974: d78ec: goto B207f; Fe9d2: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto C4061; d5011: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto E8348; B3df8: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Dc2d9; d79ae: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto b3478; E5589: $csr = $csrGenerator->generate(); goto A2718; a630b: $reverseProxySite->setDomainName($domainName); goto b20ff; dacda: if (!(true === is_null($subdomain))) { goto Bb0d5; } goto d51f6; b7411: $reversProxySiteCreator->createRootDirectory(); goto D61d6; A02e5: $siteEntity->setDomainName($domainName); goto Fd874; Df8c2: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto deac5; Ffd0b: $siteEntity->setCertificate($certificateEntity); goto b3853; Ac26b: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\x2f\x2e\56\57\56\56\57\x72\145\163\157\165\x72\143\145\163\57\x6e\147\151\156\170\x2f\166\150\x6f\163\x74\x5f\164\x65\x6d\160\154\141\164\x65\x2f\162\145\144\151\162\x65\x63\164\55\150\x74\x74\160\x33"); goto A8e4c; d9402: goto e0adc; goto Efac5; A8e4c: e0adc: goto d572c; E8348: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto c17a7; ca56c: $siteEntity->setRootDirectory($domainName); goto B5b7d; ff8a8: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto Fe9d2; E7efa: $constraintViolationList = new ConstraintViolationList(); goto b1db8; D4135: return $siteEntity; goto Cc966; Dc2d9: throw new \Exception(implode("\x3b\40", $errorMessages)); goto aa974; B5b7d: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto Bacd1; B8917: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto e8df9; e4562: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto Ca1e2; d984a: if (!(false === empty($redirectionVhostTemplate))) { goto e77be; } goto f5645; Eefa1: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto d5011; C6106: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\57\56\x2e\57\56\56\x2f\x72\145\163\x6f\165\162\x63\145\163\57\x6e\147\151\156\170\x2f\166\150\x6f\163\164\x5f\164\x65\155\x70\x6c\x61\x74\145\x2f\x72\145\144\x69\x72\x65\143\164"); goto d9402; E7305: $this->siteEntityManager->updateEntity($siteEntity); goto D4135; Efac5: b01ac: goto Ac26b; dc7af: $certificateEntity->setDefaultCertificate(true); goto D8f36; d51f6: $subjectAlternativeNames[] = sprintf("\167\x77\167\x2e\45\x73", $domainName); goto fb1f9; Ab53a: $siteEntity->setVhostTemplate($vhostTemplate); goto De886; df018: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Df8c2; a99b5: $vhostTemplate->build(); goto Ef25a; edd67: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto a99b5; b3478: $certificateEntity->setCertificate($selfSignedCertificate); goto Ffd0b; ceaad: a9908: goto Ab53a; D9693: $subdomain = false === empty($subdomain) ? $subdomain : null; goto ff8a8; a8f5e: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto f117a; d572c: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto d984a; b20ff: $reverseProxySite->setRegistrableDomain($registrableDomain); goto Db08d; Db08d: $reverseProxySite->setSubdomain($subdomain); goto E38ed; fb1f9: Bb0d5: goto Bcbe3; f7ba4: $subjectAlternativeNames[] = $registrableDomain; goto Ff792; f5645: $vhostTemplate = sprintf("\x25\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto eacf4; Ff792: Cd33c: goto Cbea9; F41bf: $reversProxySiteCreator->reloadNginxService(); goto B8328; Ef25a: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto d6670; B41b4: $certificateEntity->setCsr($csr); goto d79ae; D61d6: $reversProxySiteCreator->createLogrotateFile(); goto a8f5e; eacf4: e77be: goto ceaad; D9c7f: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto E5589; D8f36: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto B41b4; c17a7: $reversProxySiteCreator->createUser(); goto b7411; D68ab: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto f644c; A9880: $rsaKeyGenerator = new RsaKeyGenerator(); goto B8917; Cc966: } public function installedWordPressSite(Request $request) : Response { goto f6693; C801d: $siteCredentials = $session->get("\163\x69\164\145\x43\162\145\x64\145\156\164\x69\x61\x6c\163"); goto Bcc29; a9d82: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto d2af2; Bf60c: return $response; goto D5ebe; ea435: $response = $this->redirect($this->generateUrl("\143\154\x70\137\x73\x69\164\x65\x73")); goto Fcbea; f6693: $session = $request->getSession(); goto C801d; Fcbea: goto A9d55; goto Fa0e7; Fa0e7: B7f06: goto a9d82; Bcc29: if (false === empty($siteCredentials)) { goto B7f06; } goto ea435; A08e2: return $response; goto D33bf; d2af2: $response = $this->render("\106\x72\x6f\x6e\164\145\x6e\x64\x2f\123\x69\164\145\57\116\145\167\57\x77\157\162\x64\160\x72\x65\163\x73\x2d\151\x6e\163\x74\x61\x6c\x6c\x65\x64\x2e\150\x74\155\154\x2e\164\167\151\147", ["\163\x69\x74\145\103\162\x65\144\145\x6e\164\151\141\154\163" => $siteCredentials]); goto Bf60c; D5ebe: A9d55: goto A08e2; D33bf: } private function renderSiteCredentials(array $siteCredentials) : string { goto f61b2; f61b2: $renderedCredentials = ''; goto dde81; c38c8: return $renderedCredentials; goto db7f4; Cdfa0: D27d7: goto c38c8; dde81: foreach ($siteCredentials as $section => $sectionData) { goto C88ac; C88ac: $renderedCredentials .= $section . PHP_EOL; goto eafe2; E9b12: $renderedCredentials .= PHP_EOL; goto d6522; eafe2: $renderedCredentials .= "\55\x2d\55\55\55\55\55\x2d\55\55\x2d\55\55\55\x2d\x2d\x2d\55\x2d\x2d\x2d\x2d\x2d\55\55\55\55\x2d\x2d\55\x2d\55\x2d\x2d\x2d\55\x2d\55\x2d\x2d\x2d\55\x2d\55\55\55\x2d\55\x2d\55\55\55\x2d\x2d" . PHP_EOL; goto E34da; E34da: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\45\x73\x3a\x20\45\163", $key, $value) . PHP_EOL; f0da4: } goto B7655; B7655: F5bef: goto E9b12; d6522: cd0c1: goto ff26c; ff26c: } goto Cdfa0; db7f4: } private function getVhostTemplateEntity(string $name) : mixed { goto D4958; D95fe: return $vhostTemplateEntity; goto fce3f; B4591: if (!(true === is_null($vhostTemplateEntity))) { goto A5a2d; } goto A376d; b1390: A5a2d: goto D95fe; D4958: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto B4591; A376d: throw new \Exception($this->translator->trans("\x56\150\157\163\x74\40\x54\x65\x6d\160\154\x61\164\x65\40\45\x76\x68\157\x73\x74\x54\145\155\160\154\141\x74\x65\x25\x20\144\157\x65\x73\x20\156\x6f\x74\x20\145\x78\x69\x73\164\x2e", ["\x25\166\x68\x6f\x73\x74\x54\145\x6d\160\x6c\x61\164\x65\x25" => $name])); goto b1390; fce3f: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto b3e78; b3e78: $errorMessages = []; goto da6a5; e438b: Bf18d: goto D2704; D2704: return $errorMessages; goto d6bd1; da6a5: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\45\163\72\40\x25\x73", $constraint->getPropertyPath(), $constraint->getMessage()); Be28c: } goto e438b; d6bd1: } private function generateNameFromDomainName(string $domainName) : string { goto b4c38; ab53a: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto f0599; Ccdb6: f246f: goto B658b; F8d83: $name = $explodedRegistrableDomain[0] ?? ''; goto d6a01; D1dba: $explodedRegistrableDomain = explode("\x2e", $registrableDomain); goto Be99e; d6943: $name = $explodedRegistrableDomain[0] ?? ''; goto F7d48; b4c38: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto ab53a; C13b9: $explodedSubdomain = explode("\x2e", $subdomain); goto A6ae8; f0599: $subdomain = $resolvedDomainName->subDomain()->toString(); goto D1dba; B658b: goto Ae6d8; goto cb4bd; F7d48: if (!(false === empty($subdomain))) { goto f246f; } goto C13b9; Be99e: if ("\x77\x77\167" == $subdomain) { goto C5536; } goto d6943; cb4bd: C5536: goto F8d83; c6357: return $name; goto F8bf1; A6ae8: $name = sprintf("\45\163\x2d\x25\163", $explodedRegistrableDomain[0] ?? '', implode("\55", $explodedSubdomain)); goto Ccdb6; d6a01: Ae6d8: goto c6357; F8bf1: } private function getUniqueDatabaseName(string $databaseName) : string { goto D971d; B700a: $i = 0; goto F1594; A2233: if (!(0 < $i)) { goto dfdde; } goto B1790; e981b: cd6c5: goto B700a; da765: $i++; goto a966d; F1594: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto Fbc48; Bf581: return $uniqueDatabaseName; goto aeb6e; a966d: if (true === $databaseExists) { goto Cb71f; } goto d8c5a; c8afe: dfdde: goto Cf570; d8c5a: E66c6: goto Bf581; B1790: $uniqueDatabaseName = sprintf("\x25\163\55\x25\x73", $databaseName, $i); goto c8afe; f70ba: Cb71f: goto A2233; B0543: if (!(strlen($uniqueDatabaseName) <= 3)) { goto cd6c5; } goto f6a3f; Cf570: $databaseExists = in_array($uniqueDatabaseName, $databases); goto da765; Fbc48: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto d42a8; f6a3f: $uniqueDatabaseName = sprintf("\x25\x73\x2d\144\x62", $uniqueDatabaseName); goto e981b; d42a8: $databases = $databaseConnection->getDatabases(); goto f70ba; D971d: $uniqueDatabaseName = $databaseName; goto B0543; aeb6e: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto B5e46; aba00: $uniqueDatabaseUserName = sprintf("\x25\x73\x2d\144\x62", $uniqueDatabaseUserName); goto de14f; ac3c3: $uniqueDatabaseUserName = sprintf("\45\163\x2d\45\x73", $databaseUserName, $i); goto Aa459; E883c: if (!(0 < $i)) { goto a5e82; } goto ac3c3; A7b69: if (false === is_null($databaseUserEntity)) { goto E07d5; } goto D6990; Aa459: a5e82: goto b51fb; fa3e5: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto fc713; } goto aba00; de14f: fc713: goto b1055; Ffa95: $i++; goto A7b69; B5e46: $uniqueDatabaseUserName = $databaseUserName; goto fa3e5; a6b99: E07d5: goto E883c; F1069: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto Ba02e; D6990: ae746: goto F1069; Ba02e: return $uniqueDatabaseUserName; goto A87e9; b51fb: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto Ffa95; b1055: $i = 0; goto a6b99; A87e9: } private function hasPermissions() : bool { goto ca996; ca996: $user = $this->getUser(); goto bc21a; cb703: return true; goto D4abb; D4400: return false; goto A1561; D4abb: A2c9a: goto D4400; bc21a: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto A2c9a; } goto cb703; A1561: } }
